# Generated by Django 3.1.1 on 2020-11-02 08:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('qronos_django', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='qronosimportlog',
            name='import_type',
            field=models.CharField(choices=[('Tracker', 'Tracker'), ('Stage', 'Stage'), ('Delete', 'Delete')], max_length=20),
        ),
    ]
