from django.conf import settings

DEFAULT_QRONOS_HOST = "dev.qronos.xyz"
DEFAULT_QRONOS_USER = ""
DEFAULT_QRONOS_PASSWORD = ""
DEFAULT_QRONOS_TOKEN_CACHE_KEY = "QRONOS_TOKEN"
DEFAULT_QRONOS_TOKEN_CACHE_FRACTION = 0.8
DEFAULT_QRONOS_LOGGING = True
DEFAULT_QRONOS_ID_LOGGING = False
DEFAULT_QRONOS_DATA_LOGGING = False

QRONOS_HOST = getattr(settings, "QRONOS_HOST", DEFAULT_QRONOS_HOST)
QRONOS_USER = getattr(settings, "QRONOS_USER", DEFAULT_QRONOS_USER)
QRONOS_PASSWORD = getattr(settings, "QRONOS_PASSWORD", DEFAULT_QRONOS_PASSWORD)
QRONOS_TOKEN_CACHE_KEY = getattr(settings, "QRONOS_TOKEN_CACHE_KEY", DEFAULT_QRONOS_TOKEN_CACHE_KEY)
QRONOS_TOKEN_CACHE_FRACTION = getattr(settings, "QRONOS_TOKEN_CACHE_FRACTION", DEFAULT_QRONOS_TOKEN_CACHE_FRACTION)
QRONOS_LOGGING = getattr(settings, "QRONOS_LOGGING", DEFAULT_QRONOS_LOGGING)
QRONOS_ID_LOGGING = getattr(settings, "QRONOS_ID_LOGGING", DEFAULT_QRONOS_ID_LOGGING)
QRONOS_DATA_LOGGING = getattr(settings, "QRONOS_DATA_LOGGING", DEFAULT_QRONOS_DATA_LOGGING)
