# Generated by Django 3.1.1 on 2020-10-28 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='QRonosImportLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('import_type', models.CharField(choices=[('Tracker', 'Tracker'), ('Stage', 'Stage')], max_length=20)),
                ('job_id', models.IntegerField(blank=True, null=True)),
                ('status', models.CharField(default='UNKNOWN', max_length=20)),
                ('status_updated', models.DateTimeField(blank=True, null=True)),
                ('id_log', models.TextField(blank=True)),
                ('data_log', models.TextField(blank=True)),
                ('error_log', models.TextField(blank=True)),
                ('sent', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'verbose_name': 'QRonos Import Log',
                'verbose_name_plural': 'QRonos Import Logs',
            },
        ),
    ]
